/*
 * This file is automatically generated.  DON'T EDIT THIS FILE MANUALLY.
 */

#include "sombok_constants.h"
#include "sombok.h"
#define UNICODE_VERSION "6.2.0beta"
const char *linebreak_unicode_version = UNICODE_VERSION;

const char *linebreak_propvals_EA[] = {
    "Z", "Na", "N", "A", "W", "H", "F", NULL
};
const char *linebreak_propvals_GB[] = {
    "CR", "LF", "Control", "Extend", "Prepend", "SpacingMark", "L", "V", 
    "T", "LV", "LVT", "Other", "Virama", "OtherLetter", "NonJoiner", 
    "Joiner", "After_Joiner", NULL
};
const char *linebreak_propvals_LB[] = {
    "BK", "CR", "LF", "NL", "SP", "OP", "CL", "QU", "GL", "NS", "EX", "SY", 
    "IS", "PR", "PO", "NU", "AL", "ID", "IN", "HY", "BA", "BB", "B2", "CB", 
    "ZW", "CM", "WJ", "H2", "H3", "JL", "JV", "JT", "CP", "ZJ", "SG", "AI", 
    "SA", "HL", "CJ", "XX", NULL
};
const char *linebreak_propvals_SC[] = {
    "Common", "Inherited", "Unknown", "Han", "Hangul", "Thai", "Lao", 
    "Myanmar", "Khmer", "Tai_Le", "New_Tai_Lue", "Tai_Tham", "Tai_Viet", 
    NULL
};

#define M (LINEBREAK_ACTION_MANDATORY)
#define D (LINEBREAK_ACTION_DIRECT)
#define I (LINEBREAK_ACTION_INDIRECT)
#define P (LINEBREAK_ACTION_PROHIBITED)
#define r(cc) static propval_t rule_##cc[]
/* Note: Entries related to BK, CR, CM, LF, NL aren't used by break(). */
    /* BkCrLfNlSpOpClQuGlNsExSyIsPrPoNuAlIdInHyBaBbB2CbZwCmWjH2H3JlJvJtCpZj */
r(BK)={M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(CR)={M,M,P,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(LF)={M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(NL)={M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M,M};
r(SP)={P,P,P,P,P,D,P,D,D,D,P,P,P,D,D,D,D,D,D,D,D,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(OP)={P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P,P};
r(CL)={P,P,P,P,P,D,P,I,I,P,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(QU)={P,P,P,P,P,P,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,I,P,I,P,I,I,I,I,I,P,I};
r(GL)={P,P,P,P,P,I,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,I,P,I,P,I,I,I,I,I,P,I};
r(NS)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(EX)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(SY)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(IS)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,I,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,I};
r(PR)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,I,I,D,I,I,D,D,D,P,D,P,I,I,I,I,I,P,I};
r(PO)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,I,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,I};
r(NU)={P,P,P,P,P,I,P,I,I,I,P,P,P,D,D,D,I,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P,I};
r(AL)={P,P,P,P,P,I,P,I,I,I,P,P,P,D,D,I,I,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P,I};
r(ID)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P,I};
r(IN)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(HY)={P,P,P,P,P,D,P,I,D,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(BA)={P,P,P,P,P,D,P,I,D,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(BB)={P,P,P,P,P,I,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,D,P,I,P,I,I,I,I,I,P,I};
r(B2)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,P,D,P,D,P,D,D,D,D,D,P,D};
r(CB)={P,P,P,P,P,D,P,I,I,D,P,P,P,D,D,D,D,D,D,D,D,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(ZW)={P,P,P,P,P,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,P,D,D,D,D,D,D,D,D,D};
r(CM)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,D,D,D,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,D};
r(WJ)={P,P,P,P,P,I,P,I,I,I,P,P,P,I,I,I,I,I,I,I,I,I,I,I,P,I,P,I,I,I,I,I,P,I};
r(H2)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,I,I,P,D};
r(H3)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,I,P,D};
r(JL)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,I,I,I,I,D,P,D};
r(JV)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,I,I,P,D};
r(JT)={P,P,P,P,P,D,P,I,I,I,P,P,P,D,I,D,D,D,I,I,I,D,D,D,P,D,P,D,D,D,D,I,P,D};
r(CP)={P,P,P,P,P,D,P,I,I,P,P,P,P,D,D,I,I,D,D,I,I,D,D,D,P,D,P,D,D,D,D,D,P,I};
r(ZJ)={P,P,P,P,P,I,P,I,I,I,P,P,P,D,D,I,I,I,I,I,I,D,D,D,P,D,P,D,D,D,D,D,P,I};
#undef r
propval_t *linebreak_rules[] = {
    rule_BK, rule_CR, rule_LF, rule_NL, rule_SP, rule_OP, rule_CL, rule_QU, 
    rule_GL, rule_NS, rule_EX, rule_SY, rule_IS, rule_PR, rule_PO, rule_NU, 
    rule_AL, rule_ID, rule_IN, rule_HY, rule_BA, rule_BB, rule_B2, rule_CB, 
    rule_ZW, rule_CM, rule_WJ, rule_H2, rule_H3, rule_JL, rule_JV, rule_JT, 
    rule_CP, rule_ZJ
};

size_t linebreak_rulessiz = 34;

unsigned short linebreak_prop_index[] = {
    0, 32, 64, 94, 125, 157, 189, 219, 248, 276, 307, 333, 345, 345, 363,
    345, 345, 345, 392, 343, 345, 345, 420, 345, 452, 452, 469, 498, 529,
    559, 589, 345, 620, 636, 652, 345, 681, 345, 345, 345, 345, 345, 345,
    345, 704, 721, 753, 774, 806, 345, 838, 870, 345, 345, 887, 918, 944,
    962, 983, 345, 345, 1009, 1041, 1062, 1088, 1116, 1130, 345, 345, 345,
    345, 1158, 1190, 1196, 1227, 1257, 1288, 1292, 1323, 1353, 1384, 1388,
    1419, 1445, 1384, 1388, 1477, 1507, 1288, 1525, 1557, 1587, 1617, 1620,
    1652, 1678, 1709, 1713, 1744, 1587, 1774, 1778, 1810, 1587, 1774, 1620,
    1842, 1872, 1774, 345, 1898, 1930, 1961, 1976, 2008, 345, 2039, 2071,
    2103, 345, 2135, 2167, 345, 2199, 2231, 2256, 2288, 345, 2320, 2339,
    2371, 2402, 2432, 345, 345, 345, 2464, 2464, 2464, 2496, 2496, 2520,
    2528, 2528, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 2560, 2592,
    345, 345, 345, 345, 2593, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 2625, 345, 345, 2654,
    2668, 2689, 2712, 2712, 2744, 2756, 2786, 1041, 2816, 345, 345, 345, 345,
    1610, 345, 345, 345, 2848, 2876, 2894, 2926, 2946, 2973, 345, 3005, 3037,
    3048, 3080, 3112, 3144, 345, 345, 3176, 3188, 3218, 3249, 3281, 3312,
    345, 3338, 345, 3366, 3112, 3398, 345, 345, 3430, 3461, 345, 345, 345,
    345, 345, 345, 452, 987, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 3482, 3514, 3546, 3577, 3609, 3641, 3673,
    962, 3705, 3734, 3765, 3778, 3810, 3836, 3862, 3888, 3913, 3945, 3976,
    4006, 4038, 4068, 4095, 345, 345, 4108, 4131, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 4163, 4163, 4163, 4163, 4185, 4163, 4163, 4217, 4233,
    4265, 4297, 4325, 4355, 4382, 345, 4410, 4442, 4458, 4458, 4484, 4514,
    345, 4546, 4576, 4607, 4639, 345, 4666, 4692, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 4721, 345, 4746, 4774, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 4804, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 4830, 345, 345, 345, 4862, 345, 345, 345,
    452, 4894, 4926, 345, 345, 4958, 4985, 4985, 4997, 4985, 4985, 4985,
    4985, 4985, 4985, 4995, 5017, 5049, 5081, 5113, 5142, 5171, 5203, 5142,
    5232, 5264, 5282, 4985, 4985, 4969, 4990, 4985, 5310, 4986, 4985, 5342,
    4985, 4985, 4985, 4985, 4986, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 345, 345, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 5358, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    4985, 5380, 4985, 5405, 3398, 345, 345, 345, 345, 345, 345, 345, 345,
    5424, 1041, 345, 5441, 5471, 345, 345, 5486, 345, 345, 345, 345, 345,
    345, 345, 345, 5516, 5545, 345, 5570, 1711, 5594, 5622, 5654, 1041, 5680,
    5705, 5737, 1190, 5766, 5798, 345, 345, 5824, 5853, 5885, 5917, 5933,
    5965, 5997, 345, 345, 345, 345, 345, 345, 345, 6026, 6058, 6062, 6066,
    6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058,
    6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078,
    6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070,
    6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062,
    6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082,
    6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074,
    6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066,
    6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058,
    6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078,
    6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070,
    6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062,
    6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082,
    6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074,
    6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066,
    6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058,
    6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078,
    6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070,
    6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062,
    6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082,
    6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074,
    6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066,
    6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058,
    6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078,
    6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070,
    6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062,
    6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082,
    6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074,
    6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6082, 6058, 6062, 6066,
    6070, 6074, 6078, 6082, 6058, 6062, 6066, 6070, 6074, 6078, 6110, 6135,
    2532, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167,
    6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167,
    6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167,
    6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167,
    6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167, 6167,
    6167, 6167, 6167, 6167, 6167, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 636,
    636, 636, 636, 636, 636, 636, 636, 636, 636, 636, 4985, 4985, 4985, 4985,
    4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985, 4985,
    6199, 6230, 6262, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 6278, 345, 345, 345, 345, 345, 6310, 6342, 6374, 6402,
    6433, 345, 345, 345, 6445, 6477, 6509, 6539, 6571, 6588, 6620, 6651,
    6683, 345, 345, 345, 345, 345, 345, 345, 345, 3395, 345, 345, 345, 345,
    345, 345, 6713, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 2594, 345, 2609, 345, 345, 345, 345, 345, 345, 1041, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 2602, 345, 345,
    345, 345, 345, 2594, 345, 345, 345, 345, 345, 345, 345, 6744, 6760, 6792,
    345, 345, 345, 345, 345, 345, 6816, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 6848, 6856, 6882, 1035, 3281, 6898, 3396, 6930, 5468,
    6956, 3394, 345, 3281, 6988, 7020, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 7046, 1041, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 7070, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    7090, 345, 7120, 345, 345, 345, 345, 345, 345, 7130, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 7158, 7175,
    7206, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 7238, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 7265,
    7294, 7316, 345, 345, 345, 345, 7346, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 7364, 7378, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    7410, 7428, 4163, 7450, 7466, 345, 345, 7493, 7525, 4990, 7548, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345, 345,
    345, 345, 345, 345, 345, 345, 345, 345, 345
};

propval_t linebreak_prop_array[] = {
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_BA, EA_Z, GB_Control, SC_Unknown,
    LB_LF, EA_Z, GB_LF, SC_Unknown, LB_BK, EA_Z, GB_Control, SC_Unknown,
    LB_BK, EA_Z, GB_Control, SC_Unknown, LB_CR, EA_Z, GB_CR, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_SP, EA_Na, GB_Other, SC_Unknown, LB_EX, EA_Na, GB_Other, SC_Unknown,
    LB_QU, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_PO, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_QU, EA_Na, GB_Other, SC_Unknown,
    LB_OP, EA_Na, GB_Other, SC_Unknown, LB_CP, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_PR, EA_Na, GB_Other, SC_Unknown,
    LB_IS, EA_Na, GB_Other, SC_Unknown, LB_HY, EA_Na, GB_Other, SC_Unknown,
    LB_IS, EA_Na, GB_Other, SC_Unknown, LB_SY, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_NU, EA_Na, GB_Other, SC_Unknown, LB_NU, EA_Na, GB_Other, SC_Unknown,
    LB_IS, EA_Na, GB_Other, SC_Unknown, LB_IS, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_EX, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_CP, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_OP, EA_Na, GB_Other, SC_Unknown,
    LB_BA, EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_NL, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown,
    LB_CM, EA_Z, GB_Control, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown,
    LB_OP, EA_A, GB_Other, SC_Unknown, LB_PO, EA_Na, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_PR, EA_A, GB_Other, SC_Unknown,
    LB_PR, EA_Na, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_QU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_Na, GB_Other, SC_Unknown,
    LB_BA, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_Na, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown,
    LB_PR, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_BB, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_QU, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_OP, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_BB, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB, EA_A, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_GL, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_GL, EA_Z, GB_Extend, SC_Unknown,
    LB_GL, EA_Z, GB_Extend, SC_Unknown, LB_GL, EA_Z, GB_Extend, SC_Unknown,
    LB_GL, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_IS, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown,
    LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown,
    LB_PO, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown,
    LB_IS, EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_PO, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_IS, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PR, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_SpacingMark, SC_Thai,
    LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA,
    EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Virama, SC_Thai, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other,
    SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai,
    LB_SA, EA_N, GB_Other, SC_Thai, LB_SA, EA_N, GB_Other, SC_Thai, LB_SA,
    EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_SA, EA_Z,
    GB_Extend, SC_Thai, LB_SA, EA_Z, GB_Extend, SC_Thai, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA,
    EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA,
    EA_Z, GB_Extend, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N,
    GB_SpacingMark, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA,
    EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_SA, EA_Z,
    GB_Extend, SC_Lao, LB_SA, EA_Z, GB_Extend, SC_Lao, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao, LB_SA, EA_N, GB_Other, SC_Lao,
    LB_SA, EA_N, GB_Other, SC_Lao, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_BB,
    EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_BA, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_GL, EA_N,
    GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z,
    GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z,
    GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Virama, SC_Myanmar, LB_SA,
    EA_Z, GB_Virama, SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar,
    LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Extend,
    SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other,
    SC_Myanmar, LB_SA, EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_N,
    GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA,
    EA_N, GB_SpacingMark, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar,
    LB_SA, EA_Z, GB_Extend, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_Z, GB_Extend, SC_Myanmar,
    LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_N, GB_Other, SC_Khmer, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_N,
    GB_SpacingMark, SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA,
    EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_N, GB_SpacingMark, SC_Khmer,
    LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer,
    LB_SA, EA_N, GB_SpacingMark, SC_Khmer, LB_SA, EA_N, GB_SpacingMark,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Extend,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_SA, EA_Z, GB_Virama,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_NS, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Khmer, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Khmer, LB_SA, EA_Z, GB_Extend, SC_Khmer, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_GL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other,
    SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_SA, EA_N, GB_Other, SC_Tai_Le, LB_SA, EA_N, GB_Other,
    SC_Tai_Le, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_SpacingMark, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA,
    EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue,
    LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N, GB_Other,
    SC_New_Tai_Lue, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_New_Tai_Lue, LB_SA, EA_N,
    GB_Other, SC_New_Tai_Lue, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N,
    GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA,
    EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_Z, GB_Virama, SC_Tai_Tham,
    LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham,
    LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark,
    SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_N,
    GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham,
    LB_SA, EA_N, GB_SpacingMark, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_SA, EA_Z, GB_Extend,
    SC_Tai_Tham, LB_SA, EA_Z, GB_Extend, SC_Tai_Tham, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_SA, EA_N, GB_Other, SC_Tai_Tham, LB_SA, EA_N, GB_Other,
    SC_Tai_Tham, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown, LB_CM,
    EA_Z, GB_Virama, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown, LB_CM, EA_N,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_ZW, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z,
    GB_NonJoiner, SC_Unknown, LB_ZJ, EA_Z, GB_Joiner, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_BA,
    EA_A, GB_Other, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_A, GB_Other, SC_Unknown, LB_B2,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_A, GB_Other, SC_Unknown, LB_QU, EA_A, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_A, GB_Other, SC_Unknown, LB_QU, EA_A, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_IN,
    EA_A, GB_Other, SC_Unknown, LB_IN, EA_A, GB_Other, SC_Unknown, LB_IN,
    EA_A, GB_Other, SC_Unknown, LB_BA, EA_A, GB_Other, SC_Unknown, LB_BK,
    EA_Z, GB_Control, SC_Unknown, LB_BK, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_GL, EA_N, GB_Other, SC_Unknown, LB_PO,
    EA_A, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_PO,
    EA_A, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_PO,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_PO,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_NS,
    EA_N, GB_Other, SC_Unknown, LB_NS, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_IS, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_NS,
    EA_N, GB_Other, SC_Unknown, LB_NS, EA_N, GB_Other, SC_Unknown, LB_NS,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_WJ, EA_Z, GB_Control, SC_Unknown, LB_AL,
    EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL,
    EA_Z, GB_Control, SC_Unknown, LB_AL, EA_Z, GB_Control, SC_Unknown, LB_AL,
    EA_N, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL,
    EA_N, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL,
    EA_N, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM,
    EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PO,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_H, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_A, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_PO, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_PR, EA_N, GB_Other, SC_Unknown, LB_PR,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_W, GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_N, GB_Other, SC_Unknown, LB_AI,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_Na, GB_Other, SC_Unknown, LB_CL, EA_Na, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_QU,
    EA_N, GB_Other, SC_Unknown, LB_QU, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_OP,
    EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_B2, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_OP, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_OP,
    EA_W, GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_CL,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_W, GB_Extend, SC_Unknown, LB_CM,
    EA_W, GB_Extend, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_CJ,
    EA_W, GB_Other, SC_Unknown, LB_CJ, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI,
    EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_EX,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA,
    EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BB, EA_N, GB_Other, SC_Unknown, LB_BB, EA_N,
    GB_Other, SC_Unknown, LB_EX, EA_N, GB_Other, SC_Unknown, LB_EX, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L,
    SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown,
    LB_JL, EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_JL,
    EA_W, GB_L, SC_Unknown, LB_JL, EA_W, GB_L, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_Virama,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_SA, EA_N,
    GB_Other, SC_Myanmar, LB_SA, EA_N, GB_Other, SC_Myanmar, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_Z,
    GB_Extend, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_Z, GB_Extend, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_SA, EA_N,
    GB_Other, SC_Tai_Viet, LB_SA, EA_N, GB_Other, SC_Tai_Viet, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU,
    EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_H2,
    EA_W, GB_LV, SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W,
    GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H2, EA_W, GB_LV,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_H3, EA_W, GB_LVT,
    SC_Unknown, LB_H3, EA_W, GB_LVT, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown,
    LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV,
    EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_JV, EA_N, GB_V,
    SC_Unknown, LB_JV, EA_N, GB_V, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T,
    SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown,
    LB_JT, EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_JT,
    EA_N, GB_T, SC_Unknown, LB_JT, EA_N, GB_T, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_HL, EA_N, GB_Other, SC_Unknown, LB_HL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_PO, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_IS, EA_W, GB_Other, SC_Unknown, LB_CL, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_IS, EA_W,
    GB_Other, SC_Unknown, LB_IS, EA_W, GB_Other, SC_Unknown, LB_EX, EA_W,
    GB_Other, SC_Unknown, LB_EX, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_IN, EA_W,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NS, EA_W, GB_Other, SC_Unknown, LB_NS, EA_W,
    GB_Other, SC_Unknown, LB_EX, EA_W, GB_Other, SC_Unknown, LB_EX, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_OP, EA_W,
    GB_Other, SC_Unknown, LB_CL, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_PR, EA_W, GB_Other, SC_Unknown, LB_PO, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_WJ, EA_Z, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_EX, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_PR, EA_F,
    GB_Other, SC_Unknown, LB_PO, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_OP, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_CL, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_CL, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_NS, EA_F,
    GB_Other, SC_Unknown, LB_NS, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_EX, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_OP, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_OP, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_OP, EA_F, GB_Other, SC_Unknown, LB_CL, EA_F,
    GB_Other, SC_Unknown, LB_CL, EA_H, GB_Other, SC_Unknown, LB_OP, EA_H,
    GB_Other, SC_Unknown, LB_CL, EA_H, GB_Other, SC_Unknown, LB_CL, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_CJ, EA_H, GB_Other, SC_Unknown, LB_CJ, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_NS, EA_H, GB_Extend, SC_Unknown, LB_NS, EA_H,
    GB_Extend, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_PO, EA_F,
    GB_Other, SC_Unknown, LB_PR, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_ID, EA_F, GB_Other, SC_Unknown, LB_ID, EA_F,
    GB_Other, SC_Unknown, LB_PR, EA_F, GB_Other, SC_Unknown, LB_PR, EA_F,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_H, GB_Other, SC_Unknown, LB_AL, EA_H,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_AL, EA_N, GB_Control, SC_Unknown, LB_AL, EA_N,
    GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z,
    GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CB, EA_N,
    GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown,
    LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Virama,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_Z, GB_Control,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z,
    GB_Virama, SC_Unknown, LB_CM, EA_Z, GB_Virama, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_Virama, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N,
    GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_Virama, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_BA, EA_N, GB_Other, SC_Unknown, LB_BA, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_OP, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_OP, EA_N, GB_Other,
    SC_Unknown, LB_CL, EA_N, GB_Other, SC_Unknown, LB_CL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown,
    LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_N,
    GB_SpacingMark, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM,
    EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID,
    EA_W, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL,
    EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM,
    EA_N, GB_SpacingMark, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown,
    LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_N, GB_SpacingMark,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_N, GB_Extend,
    SC_Unknown, LB_CM, EA_N, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Control,
    SC_Unknown, LB_CM, EA_Z, GB_Control, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_CM, EA_Z, GB_Extend, SC_Unknown, LB_CM, EA_Z, GB_Extend,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_NU, EA_N, GB_Other,
    SC_Unknown, LB_NU, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AI, EA_A, GB_Other, SC_Unknown, LB_AI, EA_A, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other,
    SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N,
    GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown,
    LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner,
    SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N,
    GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown,
    LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner,
    SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N,
    GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown,
    LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner,
    SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N,
    GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown,
    LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner,
    SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N,
    GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown,
    LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_N, GB_After_Joiner,
    SC_Unknown, LB_ID, EA_N, GB_After_Joiner, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_ID, EA_W, GB_Other, SC_Unknown, LB_ID, EA_W,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown, LB_AL, EA_N, GB_Other, SC_Unknown, LB_AL, EA_N,
    GB_Other, SC_Unknown
};

